MaintenanceModel class
Represents the maintenance status and configuration fetched from a source.
Constructors
-
MaintenanceModel({required bool isMaintained, required String message, required List<
String> allowedVersions, DateTime? startTime, DateTime? endTime}) -
const
-
MaintenanceModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
allowedVersions
→ List<
String> -
A list of app versions that should bypass maintenance mode.
final
- endTime → DateTime?
-
The scheduled end time for maintenance mode.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMaintained → bool
-
Whether maintenance mode is currently active.
final
- message → String
-
The message to display to users during maintenance.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → DateTime?
-
The scheduled start time for maintenance mode.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited